summaryrefslogtreecommitdiff
path: root/settings.py
diff options
context:
space:
mode:
Diffstat (limited to 'settings.py')
-rw-r--r--settings.py13
1 files changed, 12 insertions, 1 deletions
diff --git a/settings.py b/settings.py
index 1202e836..98819250 100644
--- a/settings.py
+++ b/settings.py
@@ -1,5 +1,5 @@
import os
# Django settings for archweb project.
## Set the debug values
DEBUG = False
@@ -54,6 +54,7 @@ TEMPLATE_CONTEXT_PROCESSORS = (
'django.core.context_processors.static',
'django.contrib.messages.context_processors.messages',
'main.context_processors.secure',
+ 'main.context_processors.branding',
)
TEMPLATE_DIRS = (
@@ -138,6 +139,16 @@ PXEBOOT_URL = 'http://repo.parabolagnulinux.org/pxeboot/'
# community bit on the end, repo.svn_root is appended)
#SVN_BASE_URL = 'svn://svn.archlinux.org/'
+MAILMAN_BASE_URL = 'https://lists.parabolagnulinux.org/'
+BUGTRACKER_URL = 'https://labs.parabola.nu/'
+
+BRANDING_APPNAME = 'parabolaweb'
+BRANDING_DISTRONAME = 'Parabola GNU/Linux-libre'
+BRANDING_SHORTNAME = 'Parabola'
+BRANDING_WIKINAME = 'ParabolaWiki'
+BRANDING_EMAIL = 'Parabola Website Notification <nobody@parabolagnulinux.org>'
+
+
## Import local settings
from local_settings import *
@@ -1,5 +1,5 @@
import os
-# Django settings for archweb project.
+# Django settings for parabolaweb project.
## Set the debug values
DEBUG = False